# not-my-board

not-my-board is a tool to manage a pool of embedded hardware setups and to
schedule and provide access to those setups over a local network. The concept is
known as a *board farm*.

Consult the [documentation](http://not-my-board.readthedocs.io) for more
details.
